!******************************************************************************!
!                                                                              !
!    class_vertices.f90                                                        !
!    is part of RECOLA2 (REcursive Computation of One Loop Amplitudes)2        !
!                                                                              !
!    Copyright (C) 2016-2018 Ansgar Denner, Jean-Nicolas Lang and              !
!                            Sandro Uccirati                                   !
!                                                                              !
!    RECOLA2 is licenced under the GNU GPL version 3,                          !
!    see COPYING for details.                                                  !
!                                                                              !
!******************************************************************************!
!                                                           .---.              !
!                                                          /  .  \             !
!                                                         |\_/|   |            !
!                                                         |   |  /|            !
!          .----------------------------------------------------' |            !
!         /  .-.   class_vertices.f90                             |            !
!        |  /   \  This code was generated with REPT1L.           |            !
!        | |\_.  | Change this file and you get what you deserve. |            !
!        |\|  | /| Author: J.N. Lang                              |            !
!        | `---' | UFO date: 07/2017                              |            !
!        |       | UFO version: 1.0                               |            !
!        |       | Generation date: 2019-02-18 11:19             /             !
!        |       |----------------------------------------------'              !
!        \       |                                                             !
!         \     /                                                              !
!          `---'                                                               !
!******************************************************************************!
module class_vertices
  use fill_couplings
  use class_particles
  use class_ctparameters
  use fill_ctparameters, only: init_CTparameters_mdl
  use particle_keys, only: createParticleConfig
  use dictionary, only: dict,dict_get_value,dict_init
  use constants_mdl, only: Nc
  implicit none
  save

  interface get_vertex_mdl
    module procedure get_vertex3_mdl, get_vertex4_mdl, get_vertexN_mdl
  end interface

  type Branch
    integer :: lorentz_id
    integer :: perm
    integer, allocatable :: couplings(:)
    integer, dimension(n_orders) :: coupling_order
    integer :: color_id
    integer :: colorfac_id
    ! Propagator extension (only supported for massive vectors)
    ! 0: Usual propagator
    ! 1: Rxi-propagator part with pole @ M_V^2
    ! 2: Rxi-propagator part with pole @ \xi*M_V^2
    integer :: pext
  end type

  type Vertex
    type(Branch), allocatable :: branch(:)
    type(Branch), allocatable :: branchCT(:)
    type(Branch), allocatable :: branchR2(:)
  end type

  logical :: vertices_init = .false.
  logical :: vertices_filled = .false.
    interface createCurrent
      module procedure createCurrent2, createCurrent3, createCurrent4,         &
      createCurrent5, createCurrent6, createCurrent7, createCurrent8
    end interface 
  integer, parameter :: n_vertices = 1220
  type(Vertex) :: vertices(0:n_vertices-1)

  ! Defines the maximum allowed number of legs participating at a vertex
  integer, parameter :: max_leg_multiplicity = 4

  integer, parameter :: FFaS0 = 1
  integer, parameter :: FFaS1 = 2
  integer, parameter :: FFaS2 = 3
  integer, parameter :: FFaV0 = 4
  integer, parameter :: FFaV1 = 5
  integer, parameter :: SVVS0 = 6
  integer, parameter :: VVS0 = 7
  integer, parameter :: UUaS0 = 8
  integer, parameter :: UUaV0 = 9
  integer, parameter :: SUUa0 = 10
  integer, parameter :: VVSS0 = 11
  integer, parameter :: FaF0 = 12
  integer, parameter :: FaF1 = 13
  integer, parameter :: VFaF0 = 14
  integer, parameter :: VFaF1 = 15
  integer, parameter :: VVV0 = 16
  integer, parameter :: FSFa0 = 17
  integer, parameter :: FSFa1 = 18
  integer, parameter :: FSFa2 = 19
  integer, parameter :: VVVV0 = 20
  integer, parameter :: FaVF0 = 21
  integer, parameter :: FaVF1 = 22
  integer, parameter :: FaFS0 = 23
  integer, parameter :: FaFS1 = 24
  integer, parameter :: FaFS2 = 25
  integer, parameter :: UaVU0 = 26
  integer, parameter :: VSVS0 = 27
  integer, parameter :: FVFa0 = 28
  integer, parameter :: FVFa1 = 29
  integer, parameter :: VUaU0 = 30
  integer, parameter :: USUa0 = 31
  integer, parameter :: VV0 = 32
  integer, parameter :: VV1 = 33
  integer, parameter :: VV2 = 34
  integer, parameter :: VV3 = 35
  integer, parameter :: VV4 = 36
  integer, parameter :: VV5 = 37
  integer, parameter :: SVSV0 = 38
  integer, parameter :: UaSU0 = 39
  integer, parameter :: FaFV0 = 40
  integer, parameter :: FaFV1 = 41
  integer, parameter :: SSSS0 = 42
  integer, parameter :: VS0 = 43
  integer, parameter :: SFFa0 = 44
  integer, parameter :: SFFa1 = 45
  integer, parameter :: SFFa2 = 46
  integer, parameter :: VUUa0 = 47
  integer, parameter :: SFaF0 = 48
  integer, parameter :: SFaF1 = 49
  integer, parameter :: SFaF2 = 50
  integer, parameter :: SVV0 = 51
  integer, parameter :: FaSF0 = 52
  integer, parameter :: FaSF1 = 53
  integer, parameter :: FaSF2 = 54
  integer, parameter :: SVS0 = 55
  integer, parameter :: FFa0 = 56
  integer, parameter :: FFa1 = 57
  integer, parameter :: VSS0 = 58
  integer, parameter :: VSV0 = 59
  integer, parameter :: SS0 = 60
  integer, parameter :: SS1 = 61
  integer, parameter :: SSVV0 = 62
  integer, parameter :: SSV0 = 63
  integer, parameter :: SV0 = 64
  integer, parameter :: SSS0 = 65
  integer, parameter :: UVUa0 = 66
  integer, parameter :: VSSV0 = 67
  integer, parameter :: UaUS0 = 68
  integer, parameter :: VFFa0 = 69
  integer, parameter :: VFFa1 = 70
  integer, parameter :: SUaU0 = 71
  integer, parameter :: UaUV0 = 72
  complex(dp), parameter :: c1 = cmplx(1d0, 0d0, kind=dp)
  character(len=20), parameter :: c1f = "1"
  complex(dp), parameter :: c2 = cmplx(-sq2/(2d0*Nc), 0d0, kind=dp)
  character(len=20), parameter :: c2f = "-sq2/(2*Nc)"
  complex(dp), parameter :: c3 = cmplx(sq2/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c3f = "sq2/2"
  complex(dp), parameter :: c4 = cmplx(0d0, sq2/2d0, kind=dp)
  character(len=20), parameter :: c4f = "i_*sq2/2"
  complex(dp), parameter :: c5 = cmplx(0d0, -sq2/2d0, kind=dp)
  character(len=20), parameter :: c5f = "-i_*sq2/2"
  complex(dp), parameter :: c6 = cmplx(-1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c6f = "-1/2"
  complex(dp), parameter :: c7 = cmplx(1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c7f = "1/2"
  complex(dp), parameter :: c8 = cmplx(-1d0/Nc, 0d0, kind=dp)
  character(len=20), parameter :: c8f = "-1/Nc"
  complex(dp), dimension(1:8) :: colorcoeffs = (/c1, c2, c3, c4, c5, c6, c7, c8&
                                               /)
  character(len=20), dimension(1:8) :: colorcoeffs_form = (/c1f, c2f, c3f, c4f &
                 , c5f, c6f, c7f, c8f/)
  integer, dimension(1:72) :: lorentz_rank = (/0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0 &
                                             , -1, -1, 1, 1, 1, 1, 1, 1, 0, 1, &
                                             1, 0, 0, 0, 1, 0, 1, 1, 1, 0, -1  &
                                             , -1, -1, -1, -1, -1, 0, 0, 0, 0, &
                                             0, -1, 1, 1, 1, 1, 1, 1, 1, 0, 1, &
                                             1, 1, 1, -1, -1, 1, 0, -1, -1, 0, &
                                             1, -1, 0, 1, 0, 0, 1, 1, 0, 1/)
  integer, dimension(1:72) :: recola_base = (/5, 9, 7, 17, 15, -2, 2, 1, 161, 1&
                                            , -4, 0, 0, 53, 58, 12, 21, 25, 27 &
                                            , -11, 57, 51, 6, 10, 8, 166, -3,  &
                                            31, 35, 162, 1, 0, 0, 0, 0, 0, 0, -&
                                            14, 1, 18, 16, -1, 0, 23, 28, 26,  &
                                            163, 43, 46, 48, 13, 45, 41, 47, 3 &
                                            , 0, 0, 4, 14, 0, 0, -12, 11, 0, 1 &
                                            , 165, -13, 1, 33, 36, 1, 164/)
  integer, dimension(1:72) :: propagator_extension = (/0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0/)
  character(len=*), parameter :: model_timestamp = "Mon Feb 18 11:18:40 2019"

  contains
    function get_timestamp_mdl() result(ret_timestamp)
      character(len=len(model_timestamp)) :: ret_timestamp
      ret_timestamp = model_timestamp
    end function get_timestamp_mdl

    function get_lorentz_rank_mdl(l_id) result(ret_lorentz_rank)
      integer, intent(in) :: l_id
      integer :: ret_lorentz_rank
      ret_lorentz_rank = lorentz_rank(l_id)
    end function get_lorentz_rank_mdl

    function get_propagator_extension_mdl(l_id) result(ret_pext)
      integer, intent(in) :: l_id
      integer :: ret_pext
      ret_pext = propagator_extension(l_id)
    end function get_propagator_extension_mdl

    function get_max_leg_multiplicity_mdl() result(ret_max_leg_multiplicity)
      integer :: ret_max_leg_multiplicity
      ret_max_leg_multiplicity = max_leg_multiplicity
    end function get_max_leg_multiplicity_mdl

    function is_model_init_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_init
    end function is_model_init_mdl

    function is_model_filled_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_filled
    end function is_model_filled_mdl

    subroutine get_vertex3_mdl(p1, p2, p3, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertex3_mdl

    subroutine get_vertex4_mdl(p1, p2, p3, p4, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3, p4
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, p4, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if
    end subroutine get_vertex4_mdl

    subroutine get_vertexN_mdl(particles, particleOut, vertex_ret)
      integer, intent(out)              :: vertex_ret
      integer, dimension(:), intent(in) :: particles
      integer, intent(in)               :: particleOut
      integer(kind=8)                   :: config
      integer                           :: address
      logical                           :: found_vertex

      call createParticleConfig(particles, particleOut, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertexN_mdl

    subroutine av(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branch(bid)%color_id = cid
      vertices(vid)%branch(bid)%colorfac_id = cfid
      vertices(vid)%branch(bid)%pext = pext
      vertices(vid)%branch(bid)%lorentz_id = lid
      vertices(vid)%branch(bid)%perm = perm
      vertices(vid)%branch(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branch(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branch(bid)%couplings(i) = cop(i)
      end do
    end subroutine av

    subroutine avCT(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchCT(bid)%color_id = cid
      vertices(vid)%branchCT(bid)%colorfac_id = cfid
      vertices(vid)%branchCT(bid)%pext = pext
      vertices(vid)%branchCT(bid)%lorentz_id = lid
      vertices(vid)%branchCT(bid)%perm = perm
      vertices(vid)%branchCT(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchCT(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchCT(bid)%couplings(i) = cop(i)
      end do
    end subroutine avCT

    subroutine avR2(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchR2(bid)%color_id = cid
      vertices(vid)%branchR2(bid)%colorfac_id = cfid
      vertices(vid)%branchR2(bid)%pext = pext
      vertices(vid)%branchR2(bid)%lorentz_id = lid
      vertices(vid)%branchR2(bid)%perm = perm
      vertices(vid)%branchR2(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchR2(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchR2(bid)%couplings(i) = cop(i)
      end do
    end subroutine avR2

    function get_colourfac_mdl(cfid)
      integer, intent(in) :: cfid
      complex(dp) :: get_colourfac_mdl
      get_colourfac_mdl = colorcoeffs(cfid)
    end function get_colourfac_mdl

    function get_colourfac_form_mdl(cfid)
      integer, intent(in) :: cfid
      character(len=20) :: get_colourfac_form_mdl
      get_colourfac_form_mdl = colorcoeffs_form(cfid)
    end function get_colourfac_form_mdl

  function get_recola_base_mdl(l_id) result(ret_rb)
      integer, intent(in) :: l_id
      integer :: ret_rb
      ret_rb = recola_base(l_id)
    end function get_recola_base_mdl

  subroutine get_vertex_branch_status_mdl(vx,xlp,branch_exists)
    integer, intent(in)  :: vx,xlp
    logical, intent(out) ::branch_exists
    select case (xlp)
    case(TreeBranch:LoopBranch)
      branch_exists = allocated(vertices(vx)%branch)
    case(CTBranch)
      branch_exists = allocated(vertices(vx)%branchCT)
    case(R2Branch)
      branch_exists = allocated(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_branch_status_mdl

  subroutine get_vertex_colour_branches_mdl(vx,xlp,cfids,nbranches)
    integer, allocatable, intent(out) :: cfids(:)
    integer, intent(out) :: nbranches
    integer, intent(in)  :: vx,xlp
    select case (xlp)
    case (TreeBranch:LoopBranch)
      allocate(cfids(size(vertices(vx)%branch)))
      cfids(:) = vertices(vx)%branch(0:)%color_id
      nbranches = size(vertices(vx)%branch)
    case(CTBranch)
      allocate(cfids(size(vertices(vx)%branchCT)))
      cfids(:) = vertices(vx)%branchCT(0:)%color_id
      nbranches = size(vertices(vx)%branchCT)
    case(R2Branch)
      allocate(cfids(size(vertices(vx)%branchR2)))
      cfids(:) = vertices(vx)%branchR2(0:)%color_id
      nbranches = size(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_colour_branches_mdl

  subroutine get_vertex_pext_mdl(vx,xlp,br,pext)
    integer, intent(in) :: vx,xlp,br
    integer, intent(out) :: pext
    select case (xlp)
    case (TreeBranch:LoopBranch)
      pext = vertices(vx)%branch(br)%pext
    case(CTBranch)
      pext = vertices(vx)%branchCT(br)%pext
    case(R2Branch)
      pext = vertices(vx)%branchR2(br)%pext
    end select
  end subroutine get_vertex_pext_mdl

  subroutine get_vertex_order_increase_mdl(vx,xlp,br,orderInc)
    integer, intent(in) :: vx,xlp,br
    integer, dimension(:), intent(out) :: orderInc
    select case (xlp)
    case (TreeBranch:LoopBranch)
      orderInc = vertices(vx)%branch(br)%coupling_order
    case(CTBranch)
      orderInc = vertices(vx)%branchCT(br)%coupling_order
    case(R2Branch)
      orderInc = vertices(vx)%branchR2(br)%coupling_order
    end select
  end subroutine get_vertex_order_increase_mdl

  subroutine get_vertex_lorentz_type_mdl(vx,xlp,br,lid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: lid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      lid = vertices(vx)%branch(br)%lorentz_id
    case(CTBranch)
      lid = vertices(vx)%branchCT(br)%lorentz_id
    case(R2Branch)
      lid = vertices(vx)%branchR2(br)%lorentz_id
    end select
  end subroutine get_vertex_lorentz_type_mdl

  subroutine get_vertex_perm_mdl(vx,xlp,br,perm)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: perm
    select case (xlp)
    case (TreeBranch:LoopBranch)
      perm = vertices(vx)%branch(br)%perm
    case(CTBranch)
      perm = vertices(vx)%branchCT(br)%perm
    case(R2Branch)
      perm = vertices(vx)%branchR2(br)%perm
    end select
  end subroutine get_vertex_perm_mdl

  subroutine get_vertex_colour_id_mdl(vx,xlp,br,cid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      cid = vertices(vx)%branch(br)%colorfac_id
    case(CTBranch)
      cid = vertices(vx)%branchCT(br)%colorfac_id
    case(R2Branch)
      cid = vertices(vx)%branchR2(br)%colorfac_id
    end select
  end subroutine get_vertex_colour_id_mdl

  function is_zero_coupling_vertex_mdl(vx,xlp,br) result(zero)
    use class_couplings, only: get_coupling_value_mdl
    use input_mdl, only: zerocut
    integer, intent(in)  :: vx,xlp,br
    logical              :: zero
    real(dp)             :: maxvalue
    integer              :: i

    zero = .false.
    select case (xlp)
    case (TreeBranch:LoopBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branch(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branch(br)%couplings(i-&
                1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(CTBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchCT(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchCT(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(R2Branch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchR2(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchR2(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    end select
  end function is_zero_coupling_vertex_mdl

  subroutine get_vertex_ncouplings_mdl(vx,xlp,br,ncouplings)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: ncouplings
    select case(xlp)
    case(TreeBranch, LoopBranch)
      ncouplings = size(vertices(vx)%branch(br)%couplings)
    case (CTBranch)
      ncouplings = size(vertices(vx)%branchCT(br)%couplings)
    case (R2Branch)
      ncouplings = size(vertices(vx)%branchR2(br)%couplings)
    end select
  end subroutine get_vertex_ncouplings_mdl

  subroutine get_vertex_coupling_ids_mdl(vx,xlp,br,cids)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cids(:)
    select case(xlp)
    case(TreeBranch, LoopBranch)
      cids(:) = vertices(vx)%branch(br)%couplings(:)
    case (CTBranch)
      cids(:) = vertices(vx)%branchCT(br)%couplings(:)
    case (R2Branch)
      cids(:) = vertices(vx)%branchR2(br)%couplings(:)
    end select
  end subroutine get_vertex_coupling_ids_mdl

    subroutine createCurrent2(P1, P2, id, check)
      integer, intent(in) :: P1, P2, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent2

    subroutine createCurrent3(P1, P2, P3, id, check)
      integer, intent(in) :: P1, P2, P3, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent3

    subroutine createCurrent4(P1, P2, P3, P4, id, check)
      integer, intent(in) :: P1, P2, P3, P4, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent4

    subroutine createCurrent5(P1, P2, P3, P4, P5, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent5

    subroutine createCurrent6(P1, P2, P3, P4, P5, P6, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent6

    subroutine createCurrent7(P1, P2, P3, P4, P5, P6, P7, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent7

    subroutine createCurrent8(P1, P2, P3, P4, P5, P6, P7, P8, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, P8, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, P8, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent8

    subroutine init_vertices_mdl()
      use constants_mdl
      use input_mdl, only: nx, error_mdl

      ! check if modelfile is compatible to drivers
      if (model_timestamp .ne. driver_timestamp) then
        call error_mdl("Model corrupted. Driver timestamp mismatch.", &
                      where='init_vertices')
      end if

      vertices_init = .true.
      call fill_couplings_mdl
      call init_CTparameters_mdl(.true.)
      call fill_CTcouplings_mdl
      call dict_init(2441)
      call createCurrents(.false.)

    end subroutine init_vertices_mdl

    subroutine createCurrents(check)
      logical, intent(in) :: check
      call createCurrent(P_WMinus, P_H, P_Z, P_GPlus, 758, check)
      call createCurrent(P_A, P_GPlus, P_H, P_WMinus, 1020, check)
      call createCurrent(P_t, P_tAnti, P_g, 614, check)
      call createCurrent(P_WPlus, P_GPlus, P_GMinus, P_WMinus, 1015, check)
      call createCurrent(P_GPlus, P_b, P_tAnti, 131, check)
      call createCurrent(P_G0, P_cAnti, P_c, 31, check)
      call createCurrent(P_G0, P_H, P_A, 1088, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, 170, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_G0, 463, check)
      call createCurrent(P_t, P_tAnti, P_A, 429, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, 737, check)
      call createCurrent(P_A, P_Z, P_GMinus, P_GPlus, 432, check)
      call createCurrent(P_GPlus, P_A, P_Z, P_GMinus, 746, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_G0, 937, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GMinus, 354, check)
      call createCurrent(P_H, P_ghWpAnti, P_ghWp, 512, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_H, 734, check)
      call createCurrent(P_Z, P_bAnti, P_b, 42, check)
      call createCurrent(P_H, P_tauPlus, P_tauMinus, 226, check)
      call createCurrent(P_WPlus, P_H, P_H, P_WMinus, 107, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_G0, 382, check)
      call createCurrent(P_G0, P_GPlus, P_Z, P_WMinus, 493, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_A, 617, check)
      call createCurrent(P_Z, P_H, P_WPlus, P_GMinus, 76, check)
      call createCurrent(P_b, P_A, P_bAnti, 839, check)
      call createCurrent(P_H, P_H, P_A, P_Z, 1093, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_A, 716, check)
      call createCurrent(P_Z, P_dAnti, P_d, 863, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, 939, check)
      call createCurrent(P_WMinus, P_Z, P_H, P_GPlus, 465, check)
      call createCurrent(P_A, P_WMinus, P_A, P_WPlus, 2, check)
      call createCurrent(P_muPlus, P_muMinus, 1064, check)
      call createCurrent(P_muMinus, P_muPlus, P_G0, 340, check)
      call createCurrent(P_bAnti, P_b, P_Z, 833, check)
      call createCurrent(P_G0, P_G0, P_G0, P_G0, 230, check)
      call createCurrent(P_G0, P_uAnti, P_u, 185, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_A, 949, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GPlus, 1013, check)
      call createCurrent(P_GPlus, P_Z, P_Z, P_GMinus, 690, check)
      call createCurrent(P_A, P_c, P_cAnti, 784, check)
      call createCurrent(P_s, P_sAnti, P_H, 126, check)
      call createCurrent(P_t, P_tAnti, P_G0, 231, check)
      call createCurrent(P_g, P_WPlus, P_WMinus, P_g, 1183, check)
      call createCurrent(P_GPlus, P_GMinus, P_g, P_g, 1157, check)
      call createCurrent(P_H, P_G0, P_G0, 787, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_Z, 343, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, 152, check)
      call createCurrent(P_d, P_WPlus, P_uAnti, 291, check)
      call createCurrent(P_Z, P_nu_tau, P_nu_tauAnti, 597, check)
      call createCurrent(P_A, P_uAnti, P_u, 973, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_A, 1031, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, 510, check)
      call createCurrent(P_WMinus, P_G0, P_G0, P_WPlus, 393, check)
      call createCurrent(P_uAnti, P_d, P_WPlus, 280, check)
      call createCurrent(P_A, P_Z, P_g, P_g, 1186, check)
      call createCurrent(P_GMinus, P_nu_mu, P_muPlus, 659, check)
      call createCurrent(P_A, P_muMinus, P_muPlus, 799, check)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_GPlus, 77, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, 902, check)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_GPlus, 1003, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, 254, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_Z, 532, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_G0, 852, check)
      call createCurrent(P_H, P_H, 1084, check)
      call createCurrent(P_Z, P_g, P_Z, P_g, 1213, check)
      call createCurrent(P_H, P_ghWp, P_ghWpAnti, 744, check)
      call createCurrent(P_uAnti, P_u, 1103, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, 265, check)
      call createCurrent(P_sAnti, P_g, P_s, 313, check)
      call createCurrent(P_GPlus, P_A, P_H, P_WMinus, 416, check)
      call createCurrent(P_G0, P_b, P_bAnti, 380, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WPlus, 46, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_Z, 668, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_H, 563, check)
      call createCurrent(P_WMinus, P_WPlus, P_WMinus, P_WPlus, 981, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, 479, check)
      call createCurrent(P_GPlus, P_G0, P_A, P_WMinus, 631, check)
      call createCurrent(P_G0, P_WMinus, P_G0, P_WPlus, 73, check)
      call createCurrent(P_A, P_dAnti, P_d, 109, check)
      call createCurrent(P_A, P_bAnti, P_b, 704, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_Z, 701, check)
      call createCurrent(P_G0, P_G0, P_Z, P_Z, 683, check)
      call createCurrent(P_sAnti, P_s, 1053, check)
      call createCurrent(P_WMinus, P_nu_mu, P_muPlus, 760, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, 980, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, P_H, 800, check)
      call createCurrent(P_WPlus, P_Z, P_G0, P_GMinus, 320, check)
      call createCurrent(P_c, P_sAnti, P_GMinus, 729, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, P_H, 754, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, 216, check)
      call createCurrent(P_g, P_GMinus, P_GPlus, P_g, 1214, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, 1046, check)
      call createCurrent(P_H, P_ghZAnti, P_ghZ, 19, check)
      call createCurrent(P_G0, P_eMinus, P_ePlus, 639, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, 578, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghWm, 119, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_Z, 296, check)
      call createCurrent(P_nu_e, P_GMinus, P_ePlus, 401, check)
      call createCurrent(P_Z, P_nu_e, P_nu_eAnti, 721, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_A, 1021, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_Z, 392, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_H, 890, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, 1085, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GPlus, 306, check)
      call createCurrent(P_Z, P_H, P_A, P_H, 1116, check)
      call createCurrent(P_Z, P_Z, P_WMinus, P_WPlus, 759, check)
      call createCurrent(P_GPlus, P_H, P_H, P_GMinus, 877, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, 419, check)
      call createCurrent(P_muMinus, P_muPlus, P_H, 766, check)
      call createCurrent(P_GPlus, P_nu_eAnti, P_eMinus, 843, check)
      call createCurrent(P_u, P_dAnti, P_WMinus, 934, check)
      call createCurrent(P_tAnti, P_GPlus, P_b, 9, check)
      call createCurrent(P_WMinus, P_dAnti, P_u, 97, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_G0, 858, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, P_H, 528, check)
      call createCurrent(P_WPlus, P_GMinus, P_GPlus, P_WMinus, 218, check)
      call createCurrent(P_dAnti, P_d, 1129, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, 374, check)
      call createCurrent(P_cAnti, P_G0, P_c, 44, check)
      call createCurrent(P_Z, P_WPlus, P_A, P_WMinus, 111, check)
      call createCurrent(P_u, P_uAnti, P_G0, 169, check)
      call createCurrent(P_s, P_A, P_sAnti, 366, check)
      call createCurrent(P_Z, P_Z, P_g, P_g, 1193, check)
      call createCurrent(P_g, P_H, P_g, 1189, check)
      call createCurrent(P_WPlus, P_Z, P_A, P_WMinus, 477, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, P_H, 245, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, 16, check)
      call createCurrent(P_GMinus, P_g, P_GPlus, P_g, 1179, check)
      call createCurrent(P_d, P_dAnti, 1141, check)
      call createCurrent(P_t, P_G0, P_tAnti, 495, check)
      call createCurrent(P_WMinus, P_GMinus, P_GPlus, P_WPlus, 837, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_A, 1102, check)
      call createCurrent(P_Z, P_GPlus, P_H, P_WMinus, 611, check)
      call createCurrent(P_g, P_d, P_dAnti, 898, check)
      call createCurrent(P_H, P_H, P_Z, P_Z, 402, check)
      call createCurrent(P_H, P_G0, P_A, 1105, check)
      call createCurrent(P_WPlus, P_A, P_H, P_GMinus, 720, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_A, 1074, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, 616, check)
      call createCurrent(P_A, P_nu_tau, P_nu_tauAnti, 1068, check)
      call createCurrent(P_Z, P_WPlus, P_Z, P_WMinus, 557, check)
      call createCurrent(P_cAnti, P_g, P_c, 414, check)
      call createCurrent(P_GMinus, P_Z, P_H, P_WPlus, 711, check)
      call createCurrent(P_A, P_cAnti, P_c, 673, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, 1038, check)
      call createCurrent(P_G0, P_H, P_Z, 584, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_A, 773, check)
      call createCurrent(P_GMinus, P_Z, P_A, P_GPlus, 237, check)
      call createCurrent(P_WPlus, P_tauMinus, P_nu_tauAnti, 233, check)
      call createCurrent(P_Z, P_A, P_G0, P_G0, 1109, check)
      call createCurrent(P_Z, P_c, P_cAnti, 529, check)
      call createCurrent(P_GMinus, P_bAnti, P_t, 791, check)
      call createCurrent(P_G0, P_Z, P_G0, P_A, 1115, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, 455, check)
      call createCurrent(P_WPlus, P_H, P_A, P_GMinus, 961, check)
      call createCurrent(P_ePlus, P_Z, P_eMinus, 344, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, 78, check)
      call createCurrent(P_bAnti, P_b, P_g, 904, check)
      call createCurrent(P_H, P_H, P_H, P_H, 922, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_Z, 894, check)
      call createCurrent(P_Z, P_G0, P_G0, P_A, 1052, check)
      call createCurrent(P_g, P_tAnti, P_t, 767, check)
      call createCurrent(P_GPlus, P_GMinus, 1217, check)
      call createCurrent(P_G0, P_g, P_g, P_G0, 1177, check)
      call createCurrent(P_eMinus, P_WPlus, P_nu_eAnti, 206, check)
      call createCurrent(P_t, P_H, P_tAnti, 467, check)
      call createCurrent(P_cAnti, P_A, P_c, 549, check)
      call createCurrent(P_g, P_g, P_H, 1209, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_G0, 258, check)
      call createCurrent(P_muPlus, P_muMinus, P_H, 198, check)
      call createCurrent(P_GPlus, P_GMinus, P_WPlus, P_WMinus, 783, check)
      call createCurrent(P_Z, P_ePlus, P_eMinus, 135, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_Z, 89, check)
      call createCurrent(P_tauPlus, P_G0, P_tauMinus, 199, check)
      call createCurrent(P_tauMinus, P_WPlus, P_nu_tauAnti, 847, check)
      call createCurrent(P_G0, P_GPlus, P_A, P_WMinus, 270, check)
      call createCurrent(P_d, P_uAnti, P_GPlus, 349, check)
      call createCurrent(P_uAnti, P_u, P_H, 859, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_G0, 567, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_Z, 333, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, 122, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_Z, 590, check)
      call createCurrent(P_H, P_H, P_Z, P_A, 1079, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_H, 386, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, 1027, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, 317, check)
      call createCurrent(P_t, P_Z, P_tAnti, 555, check)
      call createCurrent(P_H, P_tauMinus, P_tauPlus, 368, check)
      call createCurrent(P_G0, P_dAnti, P_d, 471, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, 59, check)
      call createCurrent(P_H, P_g, P_H, P_g, 1202, check)
      call createCurrent(P_GMinus, P_A, P_H, P_WPlus, 917, check)
      call createCurrent(P_g, P_G0, P_G0, P_g, 1215, check)
      call createCurrent(P_s, P_Z, P_sAnti, 100, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_Z, 409, check)
      call createCurrent(P_A, P_GMinus, P_Z, P_GPlus, 817, check)
      call createCurrent(P_t, P_GMinus, P_bAnti, 887, check)
      call createCurrent(P_GMinus, P_sAnti, P_c, 595, check)
      call createCurrent(P_A, P_A, P_GPlus, P_GMinus, 398, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, 48, check)
      call createCurrent(P_nu_e, P_WMinus, P_ePlus, 491, check)
      call createCurrent(P_H, P_cAnti, P_c, 439, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, 387, check)
      call createCurrent(P_bAnti, P_b, P_G0, 738, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_A, 99, check)
      call createCurrent(P_H, P_G0, P_H, P_G0, 698, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, 867, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_Z, 608, check)
      call createCurrent(P_G0, P_WPlus, P_Z, P_GMinus, 476, check)
      call createCurrent(P_WPlus, P_A, P_A, P_WMinus, 603, check)
      call createCurrent(P_nu_tau, P_A, P_nu_tauAnti, 1057, check)
      call createCurrent(P_H, P_H, P_GPlus, P_GMinus, 195, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, 21, check)
      call createCurrent(P_GMinus, P_dAnti, P_u, 370, check)
      call createCurrent(P_WPlus, P_nu_muAnti, P_muMinus, 525, check)
      call createCurrent(P_G0, P_WPlus, P_A, P_GMinus, 527, check)
      call createCurrent(P_muMinus, P_muPlus, P_A, 133, check)
      call createCurrent(P_G0, P_u, P_uAnti, 1007, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_G0, 171, check)
      call createCurrent(P_GMinus, P_u, P_dAnti, 761, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, 876, check)
      call createCurrent(P_WMinus, P_c, P_sAnti, 69, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, 757, check)
      call createCurrent(P_H, P_uAnti, P_u, 377, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, 438, check)
      call createCurrent(P_u, P_A, P_uAnti, 897, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, 552, check)
      call createCurrent(P_H, P_Z, P_GMinus, P_WPlus, 205, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, 628, check)
      call createCurrent(P_H, P_g, P_g, 1206, check)
      call createCurrent(P_uAnti, P_G0, P_u, 604, check)
      call createCurrent(P_A, P_u, P_uAnti, 646, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_A, 301, check)
      call createCurrent(P_Z, P_nu_muAnti, P_nu_mu, 213, check)
      call createCurrent(P_G0, P_c, P_cAnti, 321, check)
      call createCurrent(P_g, P_c, P_cAnti, 424, check)
      call createCurrent(P_WMinus, P_WPlus, P_g, P_g, 1162, check)
      call createCurrent(P_dAnti, P_d, P_Z, 351, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_G0, 874, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, 861, check)
      call createCurrent(P_G0, P_A, P_WMinus, P_GPlus, 474, check)
      call createCurrent(P_b, P_bAnti, P_G0, 807, check)
      call createCurrent(P_GPlus, P_A, P_G0, P_WMinus, 71, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, 269, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, 302, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, 977, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_Z, 1005, check)
      call createCurrent(P_g, P_H, P_H, P_g, 1158, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, 888, check)
      call createCurrent(P_H, P_Z, P_Z, 868, check)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, 449, check)
      call createCurrent(P_G0, P_A, P_WPlus, P_GMinus, 719, check)
      call createCurrent(P_tauPlus, P_A, P_tauMinus, 591, check)
      call createCurrent(P_Z, P_Z, P_GPlus, P_GMinus, 5, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_A, 1070, check)
      call createCurrent(P_WMinus, P_g, P_WPlus, P_g, 1201, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_Z, 36, check)
      call createCurrent(P_dAnti, P_GMinus, P_u, 928, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_A, 193, check)
      call createCurrent(P_cAnti, P_c, P_g, 655, check)
      call createCurrent(P_Z, P_G0, P_GPlus, P_WMinus, 82, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_G0, 214, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, 534, check)
      call createCurrent(P_ePlus, P_eMinus, P_A, 209, check)
      call createCurrent(P_A, P_A, P_H, 1171, check)
      call createCurrent(P_WPlus, P_Z, P_Z, P_WMinus, 965, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_Z, 996, check)
      call createCurrent(P_Z, P_b, P_bAnti, 633, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_Z, 796, check)
      call createCurrent(P_t, P_tAnti, P_H, 503, check)
      call createCurrent(P_g, P_A, P_g, P_Z, 1159, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_A, 771, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_A, 751, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, 110, check)
      call createCurrent(P_GMinus, P_WMinus, P_GPlus, P_WPlus, 991, check)
      call createCurrent(P_Z, P_GMinus, P_G0, P_WPlus, 32, check)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_GPlus, 621, check)
      call createCurrent(P_WPlus, P_Z, P_H, P_GMinus, 1026, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_A, 935, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_G0, 421, check)
      call createCurrent(P_G0, P_muMinus, P_muPlus, 58, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, 834, check)
      call createCurrent(P_WMinus, P_nu_e, P_ePlus, 50, check)
      call createCurrent(P_sAnti, P_s, P_H, 814, check)
      call createCurrent(P_H, P_WMinus, P_H, P_WPlus, 62, check)
      call createCurrent(P_A, P_H, P_GMinus, P_WPlus, 38, check)
      call createCurrent(P_t, P_bAnti, P_WMinus, 350, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_H, 705, check)
      call createCurrent(P_g, P_u, P_uAnti, 23, check)
      call createCurrent(P_dAnti, P_d, P_A, 860, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, 873, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, 770, check)
      call createCurrent(P_eMinus, P_A, P_ePlus, 663, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_Z, 315, check)
      call createCurrent(P_s, P_cAnti, P_WPlus, 318, check)
      call createCurrent(P_Z, P_uAnti, P_u, 115, check)
      call createCurrent(P_H, P_muMinus, P_muPlus, 118, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_A, 361, check)
      call createCurrent(P_Z, P_H, P_Z, 346, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_Z, 408, check)
      call createCurrent(P_muPlus, P_muMinus, P_G0, 976, check)
      call createCurrent(P_G0, P_A, P_H, 1060, check)
      call createCurrent(P_nu_tauAnti, P_Z, P_nu_tau, 146, check)
      call createCurrent(P_GPlus, P_nu_muAnti, P_muMinus, 210, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_H, 457, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, 162, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, 598, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, P_H, 1004, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, 35, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, 108, check)
      call createCurrent(P_GPlus, P_G0, P_G0, P_GMinus, 138, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_G0, 40, check)
      call createCurrent(P_dAnti, P_g, P_d, 415, check)
      call createCurrent(P_Z, P_Z, P_WPlus, P_WMinus, 91, check)
      call createCurrent(P_nu_eAnti, P_nu_e, 1139, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, 601, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WPlus, 556, check)
      call createCurrent(P_WPlus, P_b, P_tAnti, 836, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_A, 680, check)
      call createCurrent(P_nu_e, P_A, P_nu_eAnti, 1075, check)
      call createCurrent(P_dAnti, P_u, P_GMinus, 946, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WMinus, 845, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, 678, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, 55, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_H, 812, check)
      call createCurrent(P_H, P_GPlus, P_Z, P_WMinus, 158, check)
      call createCurrent(P_sAnti, P_s, P_A, 674, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, 448, check)
      call createCurrent(P_s, P_sAnti, 1118, check)
      call createCurrent(P_H, P_ghWm, P_ghWmAnti, 396, check)
      call createCurrent(P_G0, P_Z, 1140, check)
      call createCurrent(P_A, P_A, P_WPlus, P_WMinus, 653, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_A, 127, check)
      call createCurrent(P_H, P_sAnti, P_s, 139, check)
      call createCurrent(P_WPlus, P_g, P_WMinus, P_g, 1154, check)
      call createCurrent(P_eMinus, P_ePlus, P_Z, 384, check)
      call createCurrent(P_WMinus, P_Z, P_A, P_WPlus, 461, check)
      call createCurrent(P_WPlus, P_WMinus, P_g, P_g, 1152, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, 316, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, 909, check)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_GMinus, 30, check)
      call createCurrent(P_b, P_tAnti, P_GPlus, 1022, check)
      call createCurrent(P_tAnti, P_t, P_A, 293, check)
      call createCurrent(P_WMinus, P_H, P_H, P_WPlus, 49, check)
      call createCurrent(P_A, P_Z, P_H, P_H, 1092, check)
      call createCurrent(P_muMinus, P_A, P_muPlus, 930, check)
      call createCurrent(P_GMinus, P_ePlus, P_nu_e, 308, check)
      call createCurrent(P_u, P_uAnti, P_H, 442, check)
      call createCurrent(P_muPlus, P_WMinus, P_nu_mu, 428, check)
      call createCurrent(P_Z, P_g, P_g, P_Z, 1218, check)
      call createCurrent(P_sAnti, P_G0, P_s, 1033, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, 811, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, 285, check)
      call createCurrent(P_nu_mu, P_A, P_nu_muAnti, 1135, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_A, 750, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_H, 45, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, 583, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_H, 656, check)
      call createCurrent(P_A, P_g, P_g, P_A, 1146, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, 222, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, 353, check)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_GMinus, 482, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, 79, check)
      call createCurrent(P_G0, P_bAnti, P_b, 284, check)
      call createCurrent(P_A, P_d, P_dAnti, 404, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, 277, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_Z, 27, check)
      call createCurrent(P_g, P_A, P_g, P_A, 1198, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, 835, check)
      call createCurrent(P_H, P_WPlus, P_Z, P_GMinus, 412, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_A, 4, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, 501, check)
      call createCurrent(P_H, P_H, P_H, 352, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_A, 914, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_A, 1125, check)
      call createCurrent(P_b, P_bAnti, P_H, 41, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, 960, check)
      call createCurrent(P_GMinus, P_G0, P_G0, P_GPlus, 472, check)
      call createCurrent(P_ePlus, P_WMinus, P_nu_e, 722, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, 972, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, P_H, 768, check)
      call createCurrent(P_ePlus, P_H, P_eMinus, 752, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_A, 526, check)
      call createCurrent(P_uAnti, P_GPlus, P_d, 580, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, 916, check)
      call createCurrent(P_GMinus, P_tauPlus, P_nu_tau, 1018, check)
      call createCurrent(P_A, P_g, P_A, P_g, 1160, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_Z, 636, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_Z, 182, check)
      call createCurrent(P_Z, P_G0, P_WMinus, P_GPlus, 483, check)
      call createCurrent(P_A, P_sAnti, P_s, 929, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_A, 203, check)
      call createCurrent(P_g, P_g, P_A, P_A, 1174, check)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_GPlus, 290, check)
      call createCurrent(P_H, P_H, P_G0, P_G0, 453, check)
      call createCurrent(P_sAnti, P_A, P_s, 513, check)
      call createCurrent(P_GMinus, P_GPlus, P_WMinus, P_WPlus, 347, check)
      call createCurrent(P_A, P_G0, P_H, 1108, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_Z, 184, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, 695, check)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_GMinus, 469, check)
      call createCurrent(P_ghWm, P_H, P_ghWmAnti, 252, check)
      call createCurrent(P_A, P_GMinus, P_G0, P_WPlus, 174, check)
      call createCurrent(P_Z, P_cAnti, P_c, 822, check)
      call createCurrent(P_g, P_A, P_Z, P_g, 1211, check)
      call createCurrent(P_G0, P_g, P_G0, P_g, 1219, check)
      call createCurrent(P_GMinus, P_GPlus, P_WPlus, P_WMinus, 844, check)
      call createCurrent(P_d, P_dAnti, P_Z, 745, check)
      call createCurrent(P_ePlus, P_eMinus, P_Z, 954, check)
      call createCurrent(P_dAnti, P_H, P_d, 505, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, 1124, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, 826, check)
      call createCurrent(P_WMinus, P_A, P_A, P_WPlus, 103, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_A, 123, check)
      call createCurrent(P_A, P_G0, P_Z, P_G0, 1082, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_H, 879, check)
      call createCurrent(P_muMinus, P_WPlus, P_nu_muAnti, 714, check)
      call createCurrent(P_A, P_g, P_g, P_g, 1187, check)
      call createCurrent(P_Z, P_WPlus, P_H, P_GMinus, 684, check)
      call createCurrent(P_A, P_g, P_Z, P_g, 1205, check)
      call createCurrent(P_WPlus, P_tAnti, P_b, 101, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, 1066, check)
      call createCurrent(P_GMinus, P_GPlus, 1161, check)
      call createCurrent(P_g, P_g, P_G0, P_G0, 1147, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_H, 912, check)
      call createCurrent(P_tAnti, P_H, P_t, 3, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, 515, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WPlus, 1208, check)
      call createCurrent(P_A, P_nu_muAnti, P_nu_mu, 1107, check)
      call createCurrent(P_nu_eAnti, P_WPlus, P_eMinus, 651, check)
      call createCurrent(P_cAnti, P_s, P_GPlus, 1040, check)
      call createCurrent(P_G0, P_A, P_GMinus, P_WPlus, 1037, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WPlus, 1030, check)
      call createCurrent(P_Z, P_H, P_GPlus, P_WMinus, 803, check)
      call createCurrent(P_c, P_g, P_cAnti, 12, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, 10, check)
      call createCurrent(P_Z, P_WMinus, P_Z, P_WPlus, 305, check)
      call createCurrent(P_Z, P_GMinus, P_A, P_GPlus, 581, check)
      call createCurrent(P_c, P_cAnti, P_Z, 682, check)
      call createCurrent(P_tauPlus, P_tauMinus, 1072, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_G0, 519, check)
      call createCurrent(P_A, P_ePlus, P_eMinus, 609, check)
      call createCurrent(P_uAnti, P_u, P_g, 823, check)
      call createCurrent(P_Z, P_GPlus, P_A, P_GMinus, 397, check)
      call createCurrent(P_g, P_g, P_H, P_H, 1149, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, 458, check)
      call createCurrent(P_c, P_Z, P_cAnti, 521, check)
      call createCurrent(P_t, P_tAnti, 1080, check)
      call createCurrent(P_ePlus, P_eMinus, P_G0, 685, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, 378, check)
      call createCurrent(P_GPlus, P_GMinus, P_WMinus, P_WPlus, 81, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_G0, 147, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_G0, 906, check)
      call createCurrent(P_u, P_WMinus, P_dAnti, 831, check)
      call createCurrent(P_s, P_g, P_sAnti, 579, check)
      call createCurrent(P_tAnti, P_t, 1138, check)
      call createCurrent(P_GMinus, P_H, P_A, P_WPlus, 172, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, 941, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_Z, 731, check)
      call createCurrent(P_sAnti, P_H, P_s, 779, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_A, 629, check)
      call createCurrent(P_d, P_A, P_dAnti, 486, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, 496, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WMinus, 896, check)
      call createCurrent(P_H, P_A, P_Z, P_H, 1117, check)
      call createCurrent(P_dAnti, P_Z, P_d, 810, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_A, 589, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, 517, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_A, 792, check)
      call createCurrent(P_Z, P_u, P_uAnti, 311, check)
      call createCurrent(P_H, P_g, P_g, P_H, 1203, check)
      call createCurrent(P_muMinus, P_Z, P_muPlus, 160, check)
      call createCurrent(P_G0, P_G0, P_WMinus, P_WPlus, 507, check)
      call createCurrent(P_Z, P_G0, P_WPlus, P_GMinus, 356, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, 485, check)
      call createCurrent(P_Z, P_nu_mu, P_nu_muAnti, 635, check)
      call createCurrent(P_b, P_bAnti, P_A, 504, check)
      call createCurrent(P_nu_tau, P_WMinus, P_tauPlus, 1002, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, 201, check)
      call createCurrent(P_A, P_G0, 1097, check)
      call createCurrent(P_H, P_H, P_WMinus, P_WPlus, 460, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_A, 798, check)
      call createCurrent(P_uAnti, P_u, P_A, 829, check)
      call createCurrent(P_tAnti, P_t, P_Z, 221, check)
      call createCurrent(P_sAnti, P_WMinus, P_c, 399, check)
      call createCurrent(P_uAnti, P_u, P_G0, 637, check)
      call createCurrent(P_GPlus, P_tAnti, P_b, 875, check)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_GPlus, 11, check)
      call createCurrent(P_H, P_A, P_H, P_Z, 1061, check)
      call createCurrent(P_b, P_G0, P_bAnti, 1023, check)
      call createCurrent(P_WMinus, P_GPlus, P_GMinus, P_WPlus, 260, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_H, 654, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, 212, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, 712, check)
      call createCurrent(P_g, P_g, P_g, P_g, 713, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_Z, 56, check)
      call createCurrent(P_tAnti, P_b, P_WPlus, 229, check)
      call createCurrent(P_WMinus, P_G0, P_Z, P_GPlus, 675, check)
      call createCurrent(P_Z, P_g, P_g, P_A, 1144, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WMinus, 1178, check)
      call createCurrent(P_H, P_A, P_WMinus, P_GPlus, 774, check)
      call createCurrent(P_A, P_H, P_G0, 1099, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_A, 968, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WPlus, 840, check)
      call createCurrent(P_H, P_GPlus, P_A, P_WMinus, 607, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, 242, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_H, 531, check)
      call createCurrent(P_H, P_Z, P_WPlus, P_GMinus, 681, check)
      call createCurrent(P_uAnti, P_A, P_u, 543, check)
      call createCurrent(P_Z, P_g, P_A, P_g, 1210, check)
      call createCurrent(P_g, P_WMinus, P_WPlus, P_g, 1199, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WMinus, 915, check)
      call createCurrent(P_uAnti, P_WPlus, P_d, 1047, check)
      call createCurrent(P_Z, P_A, P_GMinus, P_GPlus, 151, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GMinus, 136, check)
      call createCurrent(P_g, P_Z, P_Z, P_g, 1150, check)
      call createCurrent(P_Z, P_H, P_WMinus, P_GPlus, 132, check)
      call createCurrent(P_G0, P_H, P_G0, 304, check)
      call createCurrent(P_G0, P_A, P_Z, P_G0, 1111, check)
      call createCurrent(P_WPlus, P_A, P_Z, P_WMinus, 113, check)
      call createCurrent(P_G0, P_Z, P_A, P_G0, 1087, check)
      call createCurrent(P_H, P_Z, P_H, P_A, 1101, check)
      call createCurrent(P_uAnti, P_H, P_u, 741, check)
      call createCurrent(P_WPlus, P_uAnti, P_d, 427, check)
      call createCurrent(P_t, P_WMinus, P_bAnti, 327, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_G0, 838, check)
      call createCurrent(P_A, P_H, P_WMinus, P_GPlus, 274, check)
      call createCurrent(P_g, P_g, P_A, P_g, 1165, check)
      call createCurrent(P_GMinus, P_Z, P_G0, P_WPlus, 809, check)
      call createCurrent(P_sAnti, P_c, P_GMinus, 820, check)
      call createCurrent(P_H, P_d, P_dAnti, 666, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_Z, 648, check)
      call createCurrent(P_Z, P_Z, P_GMinus, P_GPlus, 500, check)
      call createCurrent(P_cAnti, P_c, 1086, check)
      call createCurrent(P_WMinus, P_t, P_bAnti, 918, check)
      call createCurrent(P_g, P_g, P_A, P_Z, 1196, check)
      call createCurrent(P_Z, P_GMinus, P_H, P_WPlus, 281, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_A, 730, check)
      call createCurrent(P_muPlus, P_H, P_muMinus, 947, check)
      call createCurrent(P_GPlus, P_eMinus, P_nu_eAnti, 558, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, 84, check)
      call createCurrent(P_A, P_nu_eAnti, P_nu_e, 1114, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_Z, 677, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_G0, 264, check)
      call createCurrent(P_WMinus, P_Z, P_Z, P_WPlus, 688, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_H, 891, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_G0, 700, check)
      call createCurrent(P_H, P_GMinus, P_H, P_GPlus, 248, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, 283, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, 551, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, 689, check)
      call createCurrent(P_Z, P_G0, P_Z, P_G0, 120, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, 68, check)
      call createCurrent(P_s, P_cAnti, P_GPlus, 1039, check)
      call createCurrent(P_g, P_g, 1062, check)
      call createCurrent(P_bAnti, P_A, P_b, 632, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_G0, 570, check)
      call createCurrent(P_s, P_GPlus, P_cAnti, 786, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, P_H, 1000, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, 83, check)
      call createCurrent(P_WPlus, P_muMinus, P_nu_muAnti, 39, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, 440, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, 602, check)
      call createCurrent(P_cAnti, P_c, P_G0, 394, check)
      call createCurrent(P_dAnti, P_d, P_g, 919, check)
      call createCurrent(P_Z, P_H, P_G0, 958, check)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_GPlus, 694, check)
      call createCurrent(P_WMinus, P_G0, P_A, P_GPlus, 307, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, 724, check)
      call createCurrent(P_bAnti, P_g, P_b, 324, check)
      call createCurrent(P_b, P_Z, P_bAnti, 228, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, 256, check)
      call createCurrent(P_cAnti, P_WPlus, P_s, 87, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_A, 524, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, 620, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, 65, check)
      call createCurrent(P_u, P_uAnti, 1119, check)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_GMinus, 997, check)
      call createCurrent(P_G0, P_sAnti, P_s, 815, check)
      call createCurrent(P_b, P_bAnti, P_Z, 261, check)
      call createCurrent(P_GPlus, P_s, P_cAnti, 993, check)
      call createCurrent(P_d, P_uAnti, P_WPlus, 749, check)
      call createCurrent(P_muMinus, P_H, P_muPlus, 661, check)
      call createCurrent(P_Z, P_Z, P_G0, P_G0, 805, check)
      call createCurrent(P_A, P_H, P_GPlus, P_WMinus, 292, check)
      call createCurrent(P_muPlus, P_muMinus, P_A, 22, check)
      call createCurrent(P_nu_muAnti, P_GPlus, P_muMinus, 0, check)
      call createCurrent(P_tauPlus, P_WMinus, P_nu_tau, 623, check)
      call createCurrent(P_Z, P_Z, 1083, check)
      call createCurrent(P_s, P_sAnti, P_g, 116, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WMinus, 1182, check)
      call createCurrent(P_H, P_ghZ, P_ghZAnti, 309, check)
      call createCurrent(P_g, P_g, P_Z, P_Z, 1173, check)
      call createCurrent(P_uAnti, P_Z, P_u, 1009, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, 772, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_Z, 372, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, 425, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, 736, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, 112, check)
      call createCurrent(P_g, P_uAnti, P_u, 102, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, 194, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_A, 323, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, 417, check)
      call createCurrent(P_G0, P_s, P_sAnti, 853, check)
      call createCurrent(P_Z, P_H, P_Z, P_H, 246, check)
      call createCurrent(P_A, P_nu_mu, P_nu_muAnti, 1127, check)
      call createCurrent(P_muMinus, P_G0, P_muPlus, 94, check)
      call createCurrent(P_g, P_Z, P_g, P_Z, 1185, check)
      call createCurrent(P_g, P_g, P_Z, P_g, 1163, check)
      call createCurrent(P_WMinus, P_WPlus, 1110, check)
      call createCurrent(P_Z, P_sAnti, P_s, 848, check)
      call createCurrent(P_nu_e, P_ePlus, P_WMinus, 37, check)
      call createCurrent(P_H, P_ghWmAnti, P_ghWm, 98, check)
      call createCurrent(P_nu_mu, P_GMinus, P_muPlus, 165, check)
      call createCurrent(P_H, P_muPlus, P_muMinus, 451, check)
      call createCurrent(P_G0, P_G0, P_H, P_H, 1042, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_H, 93, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_H, 514, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, 473, check)
      call createCurrent(P_H, P_G0, P_Z, 232, check)
      call createCurrent(P_G0, P_Z, P_GMinus, P_WPlus, 488, check)
      call createCurrent(P_G0, P_WMinus, P_A, P_GPlus, 785, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_Z, 672, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, 215, check)
      call createCurrent(P_sAnti, P_s, P_Z, 367, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_G0, 332, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, 871, check)
      call createCurrent(P_WMinus, P_GPlus, 1054, check)
      call createCurrent(P_G0, P_GMinus, P_A, P_WPlus, 756, check)
      call createCurrent(P_H, P_GPlus, P_H, P_GMinus, 652, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, 828, check)
      call createCurrent(P_Z, P_G0, P_G0, P_Z, 20, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_Z, 405, check)
      call createCurrent(P_cAnti, P_c, P_H, 775, check)
      call createCurrent(P_muPlus, P_Z, P_muMinus, 596, check)
      call createCurrent(P_WPlus, P_A, P_G0, P_GMinus, 383, check)
      call createCurrent(P_G0, P_G0, P_g, P_g, 1156, check)
      call createCurrent(P_GMinus, P_Z, P_Z, P_GPlus, 435, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, 931, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, 1041, check)
      call createCurrent(P_A, P_GPlus, P_Z, P_GMinus, 818, check)
      call createCurrent(P_H, P_H, P_GMinus, P_GPlus, 572, check)
      call createCurrent(P_GMinus, P_G0, P_A, P_WPlus, 986, check)
      call createCurrent(P_WPlus, P_WMinus, P_WPlus, P_WMinus, 1012, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, 225, check)
      call createCurrent(P_nu_tau, P_Z, P_nu_tauAnti, 243, check)
      call createCurrent(P_G0, P_d, P_dAnti, 244, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, 634, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_A, 643, check)
      call createCurrent(P_bAnti, P_G0, P_b, 777, check)
      call createCurrent(P_GMinus, P_G0, P_Z, P_WPlus, 588, check)
      call createCurrent(P_H, P_Z, P_A, P_H, 1112, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_A, 723, check)
      call createCurrent(P_nu_muAnti, P_Z, P_nu_mu, 494, check)
      call createCurrent(P_G0, P_G0, P_GMinus, P_GPlus, 92, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_G0, 1035, check)
      call createCurrent(P_H, P_Z, P_G0, 788, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_H, 336, check)
      call createCurrent(P_b, P_WPlus, P_tAnti, 880, check)
      call createCurrent(P_A, P_nu_e, P_nu_eAnti, 1067, check)
      call createCurrent(P_c, P_cAnti, P_H, 15, check)
      call createCurrent(P_bAnti, P_t, P_WMinus, 241, check)
      call createCurrent(P_ePlus, P_eMinus, P_H, 480, check)
      call createCurrent(P_Z, P_H, P_H, P_A, 1073, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_Z, 545, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, 753, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_G0, 824, check)
      call createCurrent(P_muPlus, P_G0, P_muMinus, 345, check)
      call createCurrent(P_nu_eAnti, P_A, P_nu_e, 1120, check)
      call createCurrent(P_nu_tauAnti, P_WPlus, P_tauMinus, 889, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_A, 1045, check)
      call createCurrent(P_bAnti, P_Z, P_b, 167, check)
      call createCurrent(P_H, P_G0, P_G0, P_H, 498, check)
      call createCurrent(P_A, P_GMinus, P_A, P_GPlus, 856, check)
      call createCurrent(P_A, P_Z, P_G0, P_G0, 1063, check)
      call createCurrent(P_WPlus, P_eMinus, P_nu_eAnti, 940, check)
      call createCurrent(P_tAnti, P_WPlus, P_b, 522, check)
      call createCurrent(P_WMinus, P_H, P_A, P_GPlus, 173, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_Z, 234, check)
      call createCurrent(P_G0, P_tauPlus, P_tauMinus, 742, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_H, 959, check)
      call createCurrent(P_cAnti, P_H, P_c, 576, check)
      call createCurrent(P_d, P_dAnti, P_A, 857, check)
      call createCurrent(P_WMinus, P_Z, P_G0, P_GPlus, 702, check)
      call createCurrent(P_A, P_Z, 1096, check)
      call createCurrent(P_Z, P_H, P_H, P_Z, 61, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, 259, check)
      call createCurrent(P_G0, P_G0, P_H, 832, check)
      call createCurrent(P_tauPlus, P_GMinus, P_nu_tau, 410, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, 971, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, 878, check)
      call createCurrent(P_H, P_A, P_GPlus, P_WMinus, 641, check)
      call createCurrent(P_c, P_GMinus, P_sAnti, 454, check)
      call createCurrent(P_GMinus, P_A, P_Z, P_GPlus, 950, check)
      call createCurrent(P_cAnti, P_c, P_A, 272, check)
      call createCurrent(P_eMinus, P_ePlus, 1069, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, 907, check)
      call createCurrent(P_u, P_uAnti, P_A, 490, check)
      call createCurrent(P_WPlus, P_WMinus, P_WMinus, P_WPlus, 592, check)
      call createCurrent(P_c, P_cAnti, 1049, check)
      call createCurrent(P_WPlus, P_s, P_cAnti, 903, check)
      call createCurrent(P_H, P_A, P_Z, 1134, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, 697, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, 179, check)
      call createCurrent(P_H, P_eMinus, P_ePlus, 235, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, 667, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, 964, check)
      call createCurrent(P_s, P_sAnti, P_Z, 921, check)
      call createCurrent(P_WPlus, P_WMinus, 1076, check)
      call createCurrent(P_tauMinus, P_G0, P_tauPlus, 51, check)
      call createCurrent(P_G0, P_Z, P_WMinus, P_GPlus, 251, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_H, 250, check)
      call createCurrent(P_bAnti, P_H, P_b, 129, check)
      call createCurrent(P_nu_tauAnti, P_A, P_nu_tau, 1077, check)
      call createCurrent(P_G0, P_GMinus, P_G0, P_GPlus, 908, check)
      call createCurrent(P_Z, P_g, P_g, P_g, 1151, check)
      call createCurrent(P_Z, P_nu_tauAnti, P_nu_tau, 693, check)
      call createCurrent(P_Z, P_tauPlus, P_tauMinus, 782, check)
      call createCurrent(P_Z, P_Z, P_H, P_H, 219, check)
      call createCurrent(P_g, P_GPlus, P_GMinus, P_g, 1195, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, 257, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_A, 1071, check)
      call createCurrent(P_GMinus, P_nu_e, P_ePlus, 202, check)
      call createCurrent(P_g, P_s, P_sAnti, 793, check)
      call createCurrent(P_ghWp, P_H, P_ghWpAnti, 735, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, 502, check)
      call createCurrent(P_A, P_A, P_GMinus, P_GPlus, 778, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_A, 644, check)
      call createCurrent(P_eMinus, P_G0, P_ePlus, 60, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, 14, check)
      call createCurrent(P_b, P_bAnti, 1055, check)
      call createCurrent(P_H, P_Z, P_H, P_Z, 535, check)
      call createCurrent(P_muPlus, P_A, P_muMinus, 599, check)
      call createCurrent(P_WMinus, P_A, P_G0, P_GPlus, 431, check)
      call createCurrent(P_tauMinus, P_tauPlus, 1081, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_A, 191, check)
      call createCurrent(P_GPlus, P_A, P_A, P_GMinus, 204, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_Z, 1048, check)
      call createCurrent(P_WMinus, P_WPlus, P_WPlus, P_WMinus, 154, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, 533, check)
      call createCurrent(P_eMinus, P_GPlus, P_nu_eAnti, 105, check)
      call createCurrent(P_c, P_A, P_cAnti, 262, check)
      call createCurrent(P_GPlus, P_d, P_uAnti, 727, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, 371, check)
      call createCurrent(P_GPlus, P_Z, P_G0, P_WMinus, 319, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, 893, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_Z, 134, check)
      call createCurrent(P_dAnti, P_d, P_H, 286, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_A, 57, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_H, 660, check)
      call createCurrent(P_tauPlus, P_Z, P_tauMinus, 841, check)
      call createCurrent(P_d, P_G0, P_dAnti, 279, check)
      call createCurrent(P_s, P_WPlus, P_cAnti, 542, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, 211, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_G0, 130, check)
      call createCurrent(P_A, P_H, P_A, 1172, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, 363, check)
      call createCurrent(P_WPlus, P_G0, P_G0, P_WMinus, 145, check)
      call createCurrent(P_A, P_G0, P_GPlus, P_WMinus, 106, check)
      call createCurrent(P_Z, P_WMinus, P_A, P_WPlus, 63, check)
      call createCurrent(P_Z, P_A, P_H, 1098, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, 1010, check)
      call createCurrent(P_bAnti, P_b, 1091, check)
      call createCurrent(P_g, P_g, P_g, 676, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, 295, check)
      call createCurrent(P_A, P_H, P_H, P_Z, 1122, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, 249, check)
      call createCurrent(P_G0, P_Z, P_WPlus, P_GMinus, 850, check)
      call createCurrent(P_G0, P_G0, P_WPlus, P_WMinus, 938, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_A, 819, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WPlus, 1180, check)
      call createCurrent(P_cAnti, P_GPlus, P_s, 566, check)
      call createCurrent(P_WMinus, P_ePlus, P_nu_e, 509, check)
      call createCurrent(P_Z, P_G0, P_H, 207, check)
      call createCurrent(P_tAnti, P_G0, P_t, 357, check)
      call createCurrent(P_A, P_tAnti, P_t, 707, check)
      call createCurrent(P_nu_muAnti, P_A, P_nu_mu, 1100, check)
      call createCurrent(P_G0, P_WMinus, P_Z, P_GPlus, 967, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_G0, 622, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, 1001, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_A, 546, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GMinus, 200, check)
      call createCurrent(P_s, P_H, P_sAnti, 1029, check)
      call createCurrent(P_t, P_tAnti, P_Z, 658, check)
      call createCurrent(P_Z, P_A, P_g, P_g, 1176, check)
      call createCurrent(P_GPlus, P_nu_tauAnti, P_tauMinus, 143, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, 795, check)
      call createCurrent(P_tAnti, P_Z, P_t, 359, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, 797, check)
      call createCurrent(P_tauMinus, P_H, P_tauPlus, 992, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, 717, check)
      call createCurrent(P_WMinus, P_u, P_dAnti, 271, check)
      call createCurrent(P_H, P_WPlus, P_A, P_GMinus, 846, check)
      call createCurrent(P_G0, P_GMinus, P_Z, P_WPlus, 615, check)
      call createCurrent(P_G0, P_Z, P_Z, P_G0, 910, check)
      call createCurrent(P_Z, P_d, P_dAnti, 339, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_G0, 88, check)
      call createCurrent(P_Z, P_GPlus, P_Z, P_GMinus, 978, check)
      call createCurrent(P_ePlus, P_nu_e, P_GMinus, 166, check)
      call createCurrent(P_d, P_dAnti, P_H, 1014, check)
      call createCurrent(P_Z, P_WMinus, P_H, P_GPlus, 499, check)
      call createCurrent(P_c, P_cAnti, P_G0, 781, check)
      call createCurrent(P_GPlus, P_g, P_GMinus, P_g, 1207, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Z, 475, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_G0, 518, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, 441, check)
      call createCurrent(P_b, P_bAnti, P_g, 554, check)
      call createCurrent(P_WMinus, P_A, P_H, P_GPlus, 794, check)
      call createCurrent(P_A, P_Z, P_WMinus, P_WPlus, 489, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_Z, 995, check)
      call createCurrent(P_WMinus, P_tauPlus, P_nu_tau, 776, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, 842, check)
      call createCurrent(P_GMinus, P_GPlus, P_g, P_g, 1169, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, 186, check)
      call createCurrent(P_uAnti, P_g, P_u, 849, check)
      call createCurrent(P_nu_mu, P_WMinus, P_muPlus, 657, check)
      call createCurrent(P_A, P_s, P_sAnti, 699, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, 806, check)
      call createCurrent(P_Z, P_A, P_GPlus, P_GMinus, 168, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_Z, 1043, check)
      call createCurrent(P_G0, P_WPlus, P_G0, P_WMinus, 348, check)
      call createCurrent(P_GMinus, P_c, P_sAnti, 952, check)
      call createCurrent(P_H, P_ePlus, P_eMinus, 718, check)
      call createCurrent(P_WPlus, P_H, P_Z, P_GMinus, 420, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, 153, check)
      call createCurrent(P_g, P_A, P_g, P_g, 1192, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WPlus, 310, check)
      call createCurrent(P_A, P_A, P_WMinus, P_WPlus, 330, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, 1034, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_Z, 957, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_H, 1008, check)
      call createCurrent(P_A, P_WMinus, P_Z, P_WPlus, 418, check)
      call createCurrent(P_A, P_H, P_Z, 1094, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, P_H, 217, check)
      call createCurrent(P_A, P_H, P_WPlus, P_GMinus, 575, check)
      call createCurrent(P_d, P_g, P_dAnti, 282, check)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_GMinus, 341, check)
      call createCurrent(P_g, P_t, P_tAnti, 142, check)
      call createCurrent(P_G0, P_Z, P_G0, P_Z, 988, check)
      call createCurrent(P_H, P_tAnti, P_t, 273, check)
      call createCurrent(P_g, P_A, P_A, P_g, 1188, check)
      call createCurrent(P_cAnti, P_s, P_WPlus, 7, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, 28, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WMinus, 1167, check)
      call createCurrent(P_sAnti, P_Z, P_s, 827, check)
      call createCurrent(P_G0, P_Z, P_GPlus, P_WMinus, 422, check)
      call createCurrent(P_A, P_Z, P_H, 1137, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WPlus, 1175, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, 325, check)
      call createCurrent(P_GMinus, P_WPlus, 1133, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_A, 1011, check)
      call createCurrent(P_H, P_A, P_A, 1168, check)
      call createCurrent(P_G0, P_H, P_G0, P_H, 276, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, 1, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, 303, check)
      call createCurrent(P_A, P_WPlus, P_H, P_GMinus, 927, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, 1036, check)
      call createCurrent(P_nu_e, P_Z, P_nu_eAnti, 854, check)
      call createCurrent(P_Z, P_muMinus, P_muPlus, 998, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_Z, 899, check)
      call createCurrent(P_A, P_G0, P_WPlus, P_GMinus, 728, check)
      call createCurrent(P_G0, P_GPlus, P_G0, P_GMinus, 446, check)
      call createCurrent(P_dAnti, P_u, P_WMinus, 610, check)
      call createCurrent(P_uAnti, P_d, P_GPlus, 322, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_A, 413, check)
      call createCurrent(P_u, P_uAnti, P_Z, 188, check)
      call createCurrent(P_GPlus, P_H, P_Z, P_WMinus, 710, check)
      call createCurrent(P_g, P_g, P_GPlus, P_GMinus, 1184, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, 369, check)
      call createCurrent(P_GMinus, P_H, P_Z, P_WPlus, 124, check)
      call createCurrent(P_g, P_sAnti, P_s, 726, check)
      call createCurrent(P_A, P_muPlus, P_muMinus, 816, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_A, 662, check)
      call createCurrent(P_ePlus, P_nu_e, P_WMinus, 187, check)
      call createCurrent(P_H, P_A, P_GMinus, P_WPlus, 395, check)
      call createCurrent(P_nu_muAnti, P_WPlus, P_muMinus, 881, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghWp, 72, check)
      call createCurrent(P_dAnti, P_A, P_d, 95, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, 765, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GPlus, 569, check)
      call createCurrent(P_A, P_t, P_tAnti, 577, check)
      call createCurrent(P_G0, P_tAnti, P_t, 582, check)
      call createCurrent(P_G0, P_A, P_GPlus, P_WMinus, 544, check)
      call createCurrent(P_H, P_GMinus, P_A, P_WPlus, 358, check)
      call createCurrent(P_u, P_H, P_uAnti, 29, check)
      call createCurrent(P_nu_tau, P_GMinus, P_tauPlus, 481, check)
      call createCurrent(P_Z, P_tAnti, P_t, 470, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_Z, 1006, check)
      call createCurrent(P_G0, P_G0, 1204, check)
      call createCurrent(P_g, P_b, P_bAnti, 573, check)
      call createCurrent(P_A, P_b, P_bAnti, 484, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, 911, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, 407, check)
      call createCurrent(P_bAnti, P_WMinus, P_t, 733, check)
      call createCurrent(P_G0, P_G0, P_Z, P_A, 1142, check)
      call createCurrent(P_tauMinus, P_GPlus, P_nu_tauAnti, 508, check)
      call createCurrent(P_Z, P_s, P_sAnti, 335, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_Z, 649, check)
      call createCurrent(P_Z, P_t, P_tAnti, 67, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, 932, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, 709, check)
      call createCurrent(P_nu_e, P_ePlus, P_GMinus, 25, check)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_GMinus, 882, check)
      call createCurrent(P_A, P_eMinus, P_ePlus, 148, check)
      call createCurrent(P_c, P_H, P_cAnti, 813, check)
      call createCurrent(P_GPlus, P_WMinus, 1123, check)
      call createCurrent(P_A, P_Z, P_WPlus, P_WMinus, 52, check)
      call createCurrent(P_GMinus, P_nu_tau, P_tauPlus, 936, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_A, 944, check)
      call createCurrent(P_sAnti, P_s, P_g, 725, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_H, 568, check)
      call createCurrent(P_WPlus, P_d, P_uAnti, 391, check)
      call createCurrent(P_tAnti, P_b, P_GPlus, 389, check)
      call createCurrent(P_Z, P_G0, P_GMinus, P_WPlus, 895, check)
      call createCurrent(P_u, P_dAnti, P_GMinus, 802, check)
      call createCurrent(P_WPlus, P_WPlus, P_WMinus, P_WMinus, 975, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, 96, check)
      call createCurrent(P_A, P_WPlus, P_G0, P_GMinus, 933, check)
      call createCurrent(P_WMinus, P_WMinus, P_WPlus, P_WPlus, 360, check)
      call createCurrent(P_g, P_Z, P_A, P_g, 1155, check)
      call createCurrent(P_A, P_nu_tauAnti, P_nu_tau, 1058, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_G0, 869, check)
      call createCurrent(P_A, P_WPlus, P_A, P_WMinus, 989, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, 434, check)
      call createCurrent(P_g, P_G0, P_g, P_G0, 1143, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GMinus, 376, check)
      call createCurrent(P_nu_e, P_nu_eAnti, 1126, check)
      call createCurrent(P_b, P_g, P_bAnti, 670, check)
      call createCurrent(P_tAnti, P_t, P_g, 266, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_Z, 196, check)
      call createCurrent(P_g, P_cAnti, P_c, 671, check)
      call createCurrent(P_d, P_H, P_dAnti, 114, check)
      call createCurrent(P_dAnti, P_WMinus, P_u, 33, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, P_H, 364, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, 1032, check)
      call createCurrent(P_Z, P_H, P_A, 1131, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_G0, 553, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_Z, 189, check)
      call createCurrent(P_ePlus, P_G0, P_eMinus, 547, check)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_GMinus, 227, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, 150, check)
      call createCurrent(P_G0, P_A, P_G0, P_Z, 1136, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, 687, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_G0, 379, check)
      call createCurrent(P_Z, P_A, P_WMinus, P_WPlus, 864, check)
      call createCurrent(P_H, P_H, P_g, P_g, 1191, check)
      call createCurrent(P_G0, P_t, P_tAnti, 606, check)
      call createCurrent(P_sAnti, P_c, P_WMinus, 956, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, 645, check)
      call createCurrent(P_sAnti, P_s, P_G0, 925, check)
      call createCurrent(P_s, P_sAnti, P_G0, 901, check)
      call createCurrent(P_bAnti, P_t, P_GMinus, 562, check)
      call createCurrent(P_H, P_Z, P_GPlus, P_WMinus, 945, check)
      call createCurrent(P_WPlus, P_nu_tauAnti, P_tauMinus, 224, check)
      call createCurrent(P_A, P_GMinus, P_H, P_WPlus, 299, check)
      call createCurrent(P_H, P_WMinus, P_Z, P_GPlus, 144, check)
      call createCurrent(P_A, P_WMinus, P_G0, P_GPlus, 86, check)
      call createCurrent(P_GMinus, P_WPlus, P_GPlus, P_WMinus, 236, check)
      call createCurrent(P_eMinus, P_ePlus, P_G0, 942, check)
      call createCurrent(P_u, P_G0, P_uAnti, 329, check)
      call createCurrent(P_ePlus, P_GMinus, P_nu_e, 137, check)
      call createCurrent(P_nu_eAnti, P_Z, P_nu_e, 739, check)
      call createCurrent(P_c, P_G0, P_cAnti, 983, check)
      call createCurrent(P_c, P_sAnti, P_WMinus, 747, check)
      call createCurrent(P_H, P_bAnti, P_b, 423, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, 278, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_H, 801, check)
      call createCurrent(P_WMinus, P_bAnti, P_t, 239, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_A, 715, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, 587, check)
      call createCurrent(P_uAnti, P_u, P_Z, 540, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_H, 34, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, 128, check)
      call createCurrent(P_A, P_G0, P_G0, P_Z, 1090, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, 708, check)
      call createCurrent(P_H, P_t, P_tAnti, 406, check)
      call createCurrent(P_cAnti, P_Z, P_c, 1019, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, 548, check)
      call createCurrent(P_muMinus, P_GPlus, P_nu_muAnti, 755, check)
      call createCurrent(P_GPlus, P_Z, P_H, P_WMinus, 691, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, 855, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, 456, check)
      call createCurrent(P_H, P_dAnti, P_d, 314, check)
      call createCurrent(P_A, P_GPlus, P_A, P_GMinus, 692, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, 155, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_A, 618, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, 53, check)
      call createCurrent(P_GMinus, P_H, P_H, P_GPlus, 104, check)
      call createCurrent(P_eMinus, P_ePlus, P_A, 953, check)
      call createCurrent(P_nu_mu, P_Z, P_nu_muAnti, 669, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_H, 763, check)
      call createCurrent(P_sAnti, P_GMinus, P_c, 121, check)
      call createCurrent(P_H, P_u, P_uAnti, 979, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, 388, check)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_GMinus, 342, check)
      call createCurrent(P_GPlus, P_cAnti, P_s, 686, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_A, 565, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_G0, 24, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, 762, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, 331, check)
      call createCurrent(P_H, P_A, P_G0, 1132, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, 159, check)
      call createCurrent(P_GMinus, P_g, P_g, P_GPlus, 1212, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GPlus, 1017, check)
      call createCurrent(P_GPlus, P_tauMinus, P_nu_tauAnti, 885, check)
      call createCurrent(P_H, P_s, P_sAnti, 1024, check)
      call createCurrent(P_muPlus, P_muMinus, P_Z, 564, check)
      call createCurrent(P_d, P_GPlus, P_uAnti, 8, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_G0, 769, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, 642, check)
      call createCurrent(P_H, P_c, P_cAnti, 334, check)
      call createCurrent(P_Z, P_GMinus, P_Z, P_GPlus, 696, check)
      call createCurrent(P_nu_eAnti, P_GPlus, P_eMinus, 790, check)
      call createCurrent(P_Z, P_H, P_GMinus, P_WPlus, 541, check)
      call createCurrent(P_tauMinus, P_Z, P_tauPlus, 1025, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, 64, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, 437, check)
      call createCurrent(P_GPlus, P_muMinus, P_nu_muAnti, 962, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_Z, 157, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, 90, check)
      call createCurrent(P_g, P_dAnti, P_d, 220, check)
      call createCurrent(P_d, P_dAnti, P_G0, 288, check)
      call createCurrent(P_GMinus, P_t, P_bAnti, 625, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_H, 247, check)
      call createCurrent(P_bAnti, P_b, P_H, 990, check)
      call createCurrent(P_eMinus, P_ePlus, P_H, 161, check)
      call createCurrent(P_d, P_Z, P_dAnti, 536, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_H, 630, check)
      call createCurrent(P_bAnti, P_GMinus, P_t, 444, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_Z, 593, check)
      call createCurrent(P_g, P_bAnti, P_b, 426, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, P_H, 403, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, 385, check)
      call createCurrent(P_G0, P_G0, P_A, P_Z, 1059, check)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, 312, check)
      call createCurrent(P_t, P_A, P_tAnti, 559, check)
      call createCurrent(P_ePlus, P_eMinus, 1056, check)
      call createCurrent(P_A, P_g, P_g, P_Z, 1164, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_A, 117, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_Z, 178, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, 177, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, P_H, 267, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_A, 982, check)
      call createCurrent(P_G0, P_Z, P_H, 176, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, 969, check)
      call createCurrent(P_g, P_Z, P_g, P_A, 1148, check)
      call createCurrent(P_A, P_A, P_g, P_g, 1190, check)
      call createCurrent(P_cAnti, P_c, P_Z, 411, check)
      call createCurrent(P_WMinus, P_muPlus, P_nu_mu, 886, check)
      call createCurrent(P_u, P_GMinus, P_dAnti, 183, check)
      call createCurrent(P_H, P_GMinus, P_Z, P_WPlus, 468, check)
      call createCurrent(P_Z, P_A, 1128, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, 459, check)
      call createCurrent(P_ghZ, P_H, P_ghZAnti, 626, check)
      call createCurrent(P_Z, P_eMinus, P_ePlus, 560, check)
      call createCurrent(P_A, P_GPlus, P_G0, P_WMinus, 400, check)
      call createCurrent(P_ePlus, P_A, P_eMinus, 141, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, 275, check)
      call createCurrent(P_g, P_g, P_g, P_Z, 1197, check)
      call createCurrent(P_A, P_tauMinus, P_tauPlus, 492, check)
      call createCurrent(P_c, P_cAnti, P_g, 987, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_G0, 740, check)
      call createCurrent(P_WMinus, P_sAnti, P_c, 951, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, 487, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, 647, check)
      call createCurrent(P_g, P_Z, P_g, P_g, 1181, check)
      call createCurrent(P_Z, P_tauMinus, P_tauPlus, 586, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_Z, 1028, check)
      call createCurrent(P_Z, P_WPlus, P_G0, P_GMinus, 430, check)
      call createCurrent(P_muPlus, P_GMinus, P_nu_mu, 679, check)
      call createCurrent(P_G0, P_H, P_H, P_G0, 523, check)
      call createCurrent(P_bAnti, P_b, P_A, 748, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, 664, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_G0, 294, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, 190, check)
      call createCurrent(P_A, P_tauPlus, P_tauMinus, 913, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, 70, check)
      call createCurrent(P_muMinus, P_muPlus, 1095, check)
      call createCurrent(P_A, P_G0, P_GMinus, P_WPlus, 75, check)
      call createCurrent(P_G0, P_G0, P_GPlus, P_GMinus, 180, check)
      call createCurrent(P_Z, P_A, P_WPlus, P_WMinus, 443, check)
      call createCurrent(P_H, P_WMinus, P_A, P_GPlus, 149, check)
      call createCurrent(P_GMinus, P_muPlus, P_nu_mu, 240, check)
      call createCurrent(P_d, P_dAnti, P_g, 926, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_G0, 574, check)
      call createCurrent(P_Z, P_nu_eAnti, P_nu_e, 970, check)
      call createCurrent(P_Z, P_GPlus, P_G0, P_WMinus, 923, check)
      call createCurrent(P_WPlus, P_G0, P_Z, P_GMinus, 539, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_G0, 1044, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_A, 13, check)
      call createCurrent(P_G0, P_muPlus, P_muMinus, 865, check)
      call createCurrent(P_GPlus, P_uAnti, P_d, 436, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, 640, check)
      call createCurrent(P_GMinus, P_A, P_G0, P_WPlus, 851, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, P_H, 984, check)
      call createCurrent(P_H, P_H, P_WPlus, P_WMinus, 520, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, 268, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_Z, 516, check)
      call createCurrent(P_G0, P_tauMinus, P_tauPlus, 433, check)
      call createCurrent(P_eMinus, P_H, P_ePlus, 238, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, 181, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, 538, check)
      call createCurrent(P_A, P_H, P_Z, P_H, 1104, check)
      call createCurrent(P_g, P_H, P_g, P_H, 1145, check)
      call createCurrent(P_H, P_b, P_bAnti, 66, check)
      call createCurrent(P_b, P_GPlus, P_tAnti, 600, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_Z, 530, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, 825, check)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_GPlus, 872, check)
      call createCurrent(P_Z, P_A, P_H, P_H, 1050, check)
      call createCurrent(P_dAnti, P_G0, P_d, 466, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, 924, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Z, 298, check)
      call createCurrent(P_A, P_A, 1106, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, 966, check)
      call createCurrent(P_H, P_WPlus, P_H, P_WMinus, 550, check)
      call createCurrent(P_Z, P_Z, P_H, 804, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_H, 627, check)
      call createCurrent(P_muMinus, P_muPlus, P_Z, 870, check)
      call createCurrent(P_eMinus, P_Z, P_ePlus, 650, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, 390, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, 594, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, 1078, check)
      call createCurrent(P_GPlus, P_WPlus, P_GMinus, P_WMinus, 619, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, 883, check)
      call createCurrent(P_g, P_g, P_GMinus, P_GPlus, 1153, check)
      call createCurrent(P_WPlus, P_cAnti, P_s, 506, check)
      call createCurrent(P_Z, P_muPlus, P_muMinus, 47, check)
      call createCurrent(P_WMinus, P_nu_tau, P_tauPlus, 703, check)
      call createCurrent(P_WPlus, P_nu_eAnti, P_eMinus, 381, check)
      call createCurrent(P_WMinus, P_A, P_Z, P_WPlus, 297, check)
      call createCurrent(P_tAnti, P_t, P_G0, 17, check)
      call createCurrent(P_A, P_WMinus, P_H, P_GPlus, 337, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, 85, check)
      call createCurrent(P_b, P_tAnti, P_WPlus, 955, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, 478, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_G0, 892, check)
      call createCurrent(P_tAnti, P_g, P_t, 300, check)
      call createCurrent(P_s, P_G0, P_sAnti, 6, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_Z, 624, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, 156, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, 197, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, 571, check)
      call createCurrent(P_H, P_A, P_WPlus, P_GMinus, 18, check)
      call createCurrent(P_GPlus, P_WMinus, P_GMinus, P_WPlus, 365, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, 450, check)
      call createCurrent(P_tAnti, P_t, P_H, 253, check)
      call createCurrent(P_u, P_uAnti, P_g, 561, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WPlus, 511, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_A, 1130, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, 362, check)
      call createCurrent(P_GPlus, P_H, P_A, P_WMinus, 326, check)
      call createCurrent(P_A, P_Z, P_GPlus, P_GMinus, 585, check)
      call createCurrent(P_t, P_bAnti, P_GMinus, 338, check)
      call createCurrent(P_t, P_g, P_tAnti, 862, check)
      call createCurrent(P_Z, P_WMinus, P_G0, P_GPlus, 830, check)
      call createCurrent(P_Z, P_G0, 1065, check)
      call createCurrent(P_GMinus, P_A, P_A, P_GPlus, 665, check)
      call createCurrent(P_GPlus, P_g, P_g, P_GMinus, 1200, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_H, 80, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_A, 54, check)
      call createCurrent(P_ghZAnti, P_H, P_ghZ, 375, check)
      call createCurrent(P_tauPlus, P_H, P_tauMinus, 140, check)
      call createCurrent(P_tauMinus, P_A, P_tauPlus, 452, check)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_GPlus, 963, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, 328, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_H, 900, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_Z, 163, check)
      call createCurrent(P_A, P_G0, P_WMinus, P_GPlus, 999, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, 780, check)
      call createCurrent(P_WPlus, P_GMinus, 1121, check)
      call createCurrent(P_GPlus, P_Z, P_A, P_GMinus, 808, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_G0, 884, check)
      call createCurrent(P_u, P_g, P_uAnti, 43, check)
      call createCurrent(P_GPlus, P_G0, P_Z, P_WMinus, 943, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, 994, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_Z, 1016, check)
      call createCurrent(P_g, P_g, P_Z, P_A, 1170, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_G0, 612, check)
      call createCurrent(P_WPlus, P_G0, P_A, P_GMinus, 263, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_Z, 866, check)
      call createCurrent(P_G0, P_A, 1089, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_H, 789, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_Z, 743, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, 125, check)
      call createCurrent(P_nu_tauAnti, P_GPlus, P_tauMinus, 447, check)
      call createCurrent(P_A, P_WPlus, P_Z, P_WMinus, 537, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, 164, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, 638, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_A, 706, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, 985, check)
      call createCurrent(P_G0, P_ePlus, P_eMinus, 445, check)
      call createCurrent(P_g, P_GMinus, P_g, P_GPlus, 1194, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, 732, check)
      call createCurrent(P_b, P_H, P_bAnti, 464, check)
      call createCurrent(P_H, P_Z, P_WMinus, P_GPlus, 287, check)
      call createCurrent(P_tAnti, P_A, P_t, 613, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_Z, 373, check)
      call createCurrent(P_Z, P_G0, P_A, P_G0, 1051, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GPlus, 497, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WMinus, 289, check)
      call createCurrent(P_c, P_cAnti, P_A, 920, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, 948, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_Z, 974, check)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_GMinus, 905, check)
      call createCurrent(P_c, P_WMinus, P_sAnti, 192, check)
      call createCurrent(P_u, P_Z, P_uAnti, 223, check)
      call createCurrent(P_H, P_Z, P_Z, P_H, 355, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_H, 255, check)
      call createCurrent(P_g, P_GPlus, P_g, P_GMinus, 1166, check)
      call createCurrent(P_H, P_Z, P_A, 1113, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, 605, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_A, 26, check)
      call createCurrent(P_g, P_g, P_g, P_A, 1216, check)
      call createCurrent(P_s, P_sAnti, P_A, 175, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GPlus, 821, check)
      call createCurrent(P_dAnti, P_d, P_G0, 462, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, 74, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, 764, check)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_GPlus, 208, check)
    end subroutine createCurrents

    subroutine check_vertices_mdl()
      call createCurrents(.true.)
    end subroutine check_vertices_mdl

    subroutine get_vertex_lorentz_rank_mdl(ty,cc,mr)
      integer, intent(in) :: ty
      logical, intent(in) :: cc(0:)
      integer, intent(out) :: mr
      select case(ty)
      case(9)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(14)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(15)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(16)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(17)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(18)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(19)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(21)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(22)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(26)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(28)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(29)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(30)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(44)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(45)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(46)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(47)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(48)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(49)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(50)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(52)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(53)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(54)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(55)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(58)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(63)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(66)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(69)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(70)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(72)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case default
        mr = 0
      end select 
    end subroutine get_vertex_lorentz_rank_mdl
end module class_vertices
